@@ -1,6 +1,7 @@
 from .add import add  # noqa: F401, pylint: disable=unused-import
 from .build import build  # noqa: F401, pylint: disable=unused-import
 from .checkout import checkout  # noqa: F401, pylint: disable=unused-import
+from .diff import diff  # noqa: F401, pylint: disable=unused-import
 from .index import *  # noqa: F401,F403, pylint: disable=unused-import
 from .save import md5, save  # noqa: F401, pylint: disable=unused-import
 from .serialize import (  # noqa: F401, pylint: disable=unused-import
@@ -9,6 +10,7 @@ from .serialize import (  # noqa: F401, pylint: disable=unused-import
     write_db,
     write_json,
 )
+from .update import update  # noqa: F401, pylint: disable=unused-import
 from .view import (  # noqa: F401, pylint: disable=unused-import
     DataIndexView,
     view,
